import React from "react";
import PropTypes from "prop-types";
import {
  ListItem,
  ListItemText,
  ListItemIcon,
  Link,
  Tooltip
} from "@material-ui/core";

const ContactOption = ({ tooltip, label, link, onClick, ...props }) => {
  const linkLabel = label ?? link;
  return (
    <ListItem dense>
      <ListItemIcon>
        <props.icon />
      </ListItemIcon>
      <ListItemText
        primary={
          <Tooltip title={tooltip}>
            {onClick ? (
              <Link href="#" onClick={onClick}>
                {linkLabel}
              </Link>
            ) : (
              <Link href={link} target="_blank">
                {linkLabel}
              </Link>
            )}
          </Tooltip>
        }
      />
    </ListItem>
  );
};

ContactOption.propTypes = {
  icon: PropTypes.object.isRequired,
  tooltip: PropTypes.string.isRequired,
  label: PropTypes.string,
  link: PropTypes.string.isRequired,
  onClick: PropTypes.func
};

export default ContactOption;
