import React from "react";
import PropTypes from "prop-types";
import {
  Grid,
  List,
  ListItem,
  ListItemText,
  ListItemIcon,
  Link,
  IconButton,
  Tooltip
} from "@material-ui/core";
import UserProfilePicture from "./UserProfilePicture";
import { FileCopyOutlined } from "@material-ui/icons";
import ContactOptions from "./ContactOptions";
import { useClipboard } from "../../../../hooks";
import { useTranslation } from "react-i18next";
import { makeStyles } from "@material-ui/core/styles";
import styles from "../styles";

const useStyles = makeStyles(styles);

const UserProfileCardContent = ({ userData }) => {
  const { profilePictureUrl } = userData;
  const { t } = useTranslation();
  const classes = useStyles();
  const { copy } = useClipboard();

  const userName = `${userData.firstName} ${userData.lastName}`;

  return (
    <div className={classes.panel}>
      <UserProfilePicture pictureUrl={userData.profilePictureUrl} />
      <Grid container spacing={2}>
        <Grid item xs={12} sm={6}>
          <List>
            <ContactOptions
              contactOptions={userData.contactOptions}
              userName={userName}
            />
            {profilePictureUrl && (
              <ListItem dense>
                <ListItemIcon>
                  <Tooltip title={t("Generic.Copy")}>
                    <IconButton size="small" onClick={copy(profilePictureUrl)}>
                      <FileCopyOutlined />
                    </IconButton>
                  </Tooltip>
                </ListItemIcon>
                <ListItemText
                  primary={
                    <Tooltip title={t("Generic.OpenInNewTab")}>
                      <Link href={profilePictureUrl} target="_blank">
                        {profilePictureUrl}
                      </Link>
                    </Tooltip>
                  }
                />
              </ListItem>
            )}
          </List>
        </Grid>
      </Grid>
    </div>
  );
};

UserProfileCardContent.propTypes = {
  userData: PropTypes.object.isRequired
};

export default UserProfileCardContent;
